import re
from copy import copy
from operator import attrgetter

TASK_SLUG_REGEX = re.compile(r'[\W_]+')


def sort_tasks(tasks, field):
    sort_key = attrgetter(field)
    return _sort_tasks(tasks, sort_key)


def _sort_tasks(tasks, key):
    tasks_copy = copy(tasks)

    sorted_tasks = sorted(
        tasks_copy,
        key=key
    )

    for task in sorted_tasks:
        task.tasks = _sort_tasks(copy(task.tasks), key)

    return sorted_tasks


def slugify(name):
    return TASK_SLUG_REGEX.sub('_', name.lower())



#!/usr/bin/env python3

version_tuple = (1, 1)

with open('schedules_tools/version.py') as ver_file:
    exec(ver_file.read())

print(f"%define version {version_tuple[0]}.{version_tuple[1]}")
print(f"%define release_number {version_tuple[2]}")



#!/usr/bin/env python3

from setuptools import setup


def scm_config():
    def scheme(version):
        if version.distance is None:
            version.distance = 0

        return version.format_with('{tag}.{distance}')

    return {'version_scheme': scheme,
            'write_to': "schedules_tools/version.py",
            'local_scheme': 'dirty-tag'
            }


setup(
    use_scm_version=scm_config
)
